GeneralSipHash

Struct GeneralSipHash 

pub struct GeneralSipHash<const C: u32, const D: u32> { /* private fields */ }
Implementation of the SipHash algorithm.

This algorithm is resistant to various hash attacks when C >= 2 and D >= 4.

Notes

The HashFunction implementation returns values in little-endian order, and thus is cross-platform (with slightly better performance on little-endian platforms).

This algorithm is an implementation of the “SipHash: a fast short-input PRF” paper by Jean-Philippe Aumasson and Daniel J. Bernstein.

Implementations

Source

impl<const C: u32, const D: u32> GeneralSipHash<C, D>

pub const fn for_array_key(key: &[u8; 16]) -> Self

Creates a new GeneralSipHash instance from a given array key.

pub const fn for_slice_key(key: &[u8]) -> Self

Creates a new GeneralSipHash instance from a given slice.

Panics

If the key is not exactly 16 bytes long, this function will panic.

pub const fn for_keys(key0: u64, key1: u64) -> Self

Creates a new GeneralSipHash instance from a key pair.

pub const fn update_const(&mut self, data: &[u8])

Updates the underlying state with the given block.

Panics

If the length of the block exceeds u32::MAX.

pub const fn result_const(&self) -> u64

Calculates the final hash value.

This function does not update the internal state, and thus SipHash can still be used afterwards.